diff a/src/hotspot/share/cds/dumpAllocStats.hpp b/src/hotspot/share/cds/dumpAllocStats.hpp
--- a/src/hotspot/share/cds/dumpAllocStats.hpp
+++ b/src/hotspot/share/cds/dumpAllocStats.hpp
@@ -63,21 +63,43 @@
   CompactHashtableStats _string_stats;
 
   int _counts[2][_number_of_types];
   int _bytes [2][_number_of_types];
 
+  int _num_field_cp_entries;
+  int _num_field_cp_entries_archived;
+  int _num_field_cp_entries_excluded;
+  int _num_indy_cp_entries;
+  int _num_indy_cp_entries_archived;
+  int _num_indy_cp_entries_excluded;
   int _num_klass_cp_entries;
   int _num_klass_cp_entries_archived;
+  int _num_klass_cp_entries_excluded;
+  int _num_method_cp_entries;
+  int _num_method_cp_entries_archived;
+  int _num_method_cp_entries_excluded;
+  int _num_dynamic_proxy_classes;
 
 public:
   enum { RO = 0, RW = 1 };
 
   DumpAllocStats() {
     memset(_counts, 0, sizeof(_counts));
     memset(_bytes,  0, sizeof(_bytes));
-    _num_klass_cp_entries = 0;
-    _num_klass_cp_entries_archived = 0;
+    _num_field_cp_entries           = 0;
+    _num_field_cp_entries_archived  = 0;
+    _num_field_cp_entries_excluded    = 0;
+    _num_indy_cp_entries            = 0;
+    _num_indy_cp_entries_archived   = 0;
+    _num_indy_cp_entries_excluded     = 0;
+    _num_klass_cp_entries           = 0;
+    _num_klass_cp_entries_archived  = 0;
+    _num_klass_cp_entries_excluded    = 0;
+    _num_method_cp_entries          = 0;
+    _num_method_cp_entries_archived = 0;
+    _num_method_cp_entries_excluded   = 0;
+    _num_dynamic_proxy_classes      = 0;
   };
 
   CompactHashtableStats* symbol_stats() { return &_symbol_stats; }
   CompactHashtableStats* string_stats() { return &_string_stats; }
 
@@ -100,13 +122,36 @@
 
   void record_cpp_vtables(int byte_size) {
     _bytes[RW][CppVTablesType] += byte_size;
   }
 
+  void record_field_cp_entry(bool archived, bool erased) {
+    _num_field_cp_entries ++;
+    _num_field_cp_entries_archived += archived ? 1 : 0;
+    _num_field_cp_entries_excluded += erased ? 1 : 0;
+  }
+
+  void record_indy_cp_entry(bool archived, bool excluded) {
+    _num_indy_cp_entries ++;
+    _num_indy_cp_entries_archived += archived ? 1 : 0;
+    _num_indy_cp_entries_excluded += excluded ? 1 : 0;
+  }
+
   void record_klass_cp_entry(bool archived) {
     _num_klass_cp_entries ++;
-    _num_klass_cp_entries_archived += archived ? 1 : 0;
+    _num_klass_cp_entries_archived +=  archived ? 1 : 0;
+    _num_klass_cp_entries_excluded += !archived ? 1 : 0;
+  }
+
+  void record_method_cp_entry(bool archived, bool excluded) {
+    _num_method_cp_entries ++;
+    _num_method_cp_entries_archived += archived ? 1 : 0;
+    _num_method_cp_entries_excluded += excluded ? 1 : 0;
+  }
+
+  void record_dynamic_proxy_class() {
+    _num_dynamic_proxy_classes ++;
   }
 
   void print_stats(int ro_all, int rw_all);
 };
 
